+++
title = "Swap tags and categories"
categories = ["front-matter", "keys", "replace", "tags", "categories", "swap"]
tags = ["test-cat-x"]
draft = false
+++

This post will have the `tags` and `categories` keys in the
front-matter swapped.
